@@ -17,7 +17,7 @@ class GPSPrayerLocator(object):
         if device.fix:
             if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
                 print "lat = %f, long = %f" % device.fix[4:6]
-                self.prayerTime.calculatePrayerTimes(self.prayerTime.date,0,self.prayerTime.tz,device.fix[4],device.fix[5])
+                self.callBack(0,str(device.fix[4]),str(device.fix[5]))
                 data.stop()
     
     def on_stop(self,control, data):
@@ -43,3 +43,19 @@ class GPSPrayerLocator(object):
         gobject.idle_add(self.start_location, control)
         
         loop.run()
+
+    def locate(self,callBack):
+        self.callBack = callBack
+        loop = gobject.MainLoop()
+        control = location.GPSDControl.get_default()
+        device = location.GPSDevice()
+        control.set_properties(preferred_method=location.METHOD_USER_SELECTED,
+                               preferred_interval=location.INTERVAL_DEFAULT)
+        
+        control.connect("error-verbose", self.on_error, loop)
+        device.connect("changed", self.on_changed, control)
+        control.connect("gpsd-stopped", self.on_stop, loop)
+        
+        gobject.idle_add(self.start_location, control)
+        
+        loop.run()
\ No newline at end of file
